/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 32

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg;
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw tySequence__IeU9azYSNIK3V9b36Ir6NZcw;
typedef struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw;
typedef struct tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg;
typedef struct tySequence__q9cq1Li6c1nMjHpacEbCj0g tySequence__q9cq1Li6c1nMjHpacEbCj0g;
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct tySequence__RNhZxf20g9beyq5VBOGxhDg tySequence__RNhZxf20g9beyq5VBOGxhDg;
typedef struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ;
typedef struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ tySequence__lFbCtu5P2Kf7YDYtGjkxAQ;
typedef struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA;
typedef struct tySequence__ijtae5OneaLys0hN9alAicA tySequence__ijtae5OneaLys0hN9alAicA;
typedef struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w;
typedef struct tySequence__SerjNoUujW2dUouVBrJiCw tySequence__SerjNoUujW2dUouVBrJiCw;
typedef struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyObject_Table__r0v8BdcBPKhl73K8p2VMUA;
typedef struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g tySequence__K9agbtcb0qPZuSJFXB9cTe6g;
typedef struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg;
typedef struct tySequence__m88qdML9cQOuqGAQn6XWL1A tySequence__m88qdML9cQOuqGAQn6XWL1A;
typedef struct tyObject_Table__1hIWbTQWYT4BmhdESze57A tyObject_Table__1hIWbTQWYT4BmhdESze57A;
typedef struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ tySequence__naEbXEp9b9aiW1zXJorqf9cXQ;
typedef struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw tyObject_Table__9cHFtxtpgztIcDsypRz9byKw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA;
typedef struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw;
typedef struct tySequence__ed0C0uAUZPhvw3RAc5hfYg tySequence__ed0C0uAUZPhvw3RAc5hfYg;
typedef struct tyObject_Table__imojfg883tkWsWJwyshGqQ tyObject_Table__imojfg883tkWsWJwyshGqQ;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg tyObject_Table__BCPh85PHtwxox9bv7NLFrlg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct RootObj RootObj;
typedef struct tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ;
typedef struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA;
typedef struct tySequence__KgiZ29chkJAD01p9aLRB32qw tySequence__KgiZ29chkJAD01p9aLRB32qw;
typedef struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A tyObject_Table__LM44poVdVEn4Mo4N4L8c3A;
typedef struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw tySequence__rkYRZrbHVYL3nhXlQW3K9bw;
typedef struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ tySequence__IRFEb1e9bxgbJLuB5xrdZsQ;
typedef struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ;
typedef struct tySequence__YmPd0eWfcTfrVYrthlXPYA tySequence__YmPd0eWfcTfrVYrthlXPYA;
typedef struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q;
typedef struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg tySequence__Hz5SYwQU29b9aFLt09blvVQPg;
typedef struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg tyObject_Table__R7JnJQEipxxOlJWXQz7jWg;
typedef struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ tySequence__3G9aA9cLXaPxuRxMKm3anacQ;
typedef struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q tySequence__bPFv6ypvvCX2A9a9al8utL2Q;
typedef struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg;
typedef struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg;
typedef struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tySequence__fZ9aerq6GRgd1Id9b1cf7NuA tySequence__fZ9aerq6GRgd1Id9b1cf7NuA;
typedef struct tyTuple__D9cr9aW4733sg56WAiSRpttQ tyTuple__D9cr9aW4733sg56WAiSRpttQ;
typedef struct tySequence__vAEg9bb6P9cAvzrQae7aeKyA tySequence__vAEg9bb6P9cAvzrQae7aeKyA;
typedef struct tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tySequence__AT39bF59bUK7pfvl9asfwzQ6A tySequence__AT39bF59bUK7pfvl9asfwzQ6A;
typedef struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ;
typedef struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g tySequence__qeAsXh2i1GAL5Nl0g3OP8g;
typedef struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg;
typedef struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg;
typedef struct tySequence__4Murtwnm0Fyc7F9acrytEXw tySequence__4Murtwnm0Fyc7F9acrytEXw;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw;
typedef struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg tySequence__QnmOtn1Iv4LvxOXoMn8Rbg;
typedef struct tySequence__oKtVqsc9bQVCNyrijELM4OQ tySequence__oKtVqsc9bQVCNyrijELM4OQ;
typedef struct tySequence__qy6Iwdy00wN560qud54HTg tySequence__qy6Iwdy00wN560qud54HTg;
typedef struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ tySequence__k67v9bwvvQDmS1ynyGGUbeQ;
typedef struct tySequence__cLsClAAfd0MKkoBQVyvdvw tySequence__cLsClAAfd0MKkoBQVyvdvw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg tySequence__q9bTuOB0JXh1iZ3CSGdRLbg;
typedef struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw;
typedef struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ;
typedef struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tySequence__vKogasEnJSPhbQmA8r4Y9aA tySequence__vKogasEnJSPhbQmA8r4Y9aA;
typedef struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ;
typedef struct tySequence__C3r8jsj9chA4sIlYfDN5aDw tySequence__C3r8jsj9chA4sIlYfDN5aDw;
typedef struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ;
typedef struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg tyTuple__UluY8x0Nj6cp9b0o88wJ0lg;
typedef struct tySequence__dlD6tEGzYLLpKVq3XwuFlA tySequence__dlD6tEGzYLLpKVq3XwuFlA;
typedef struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ;
typedef struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg;
typedef struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ;
typedef struct tyTuple__rZZA0skon1OsHdiEvT8RZQ tyTuple__rZZA0skon1OsHdiEvT8RZQ;
typedef struct tySequence__6OFCSvqRaxyEgUqWtnZSlw tySequence__6OFCSvqRaxyEgUqWtnZSlw;
typedef struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q;
typedef struct tySequence__UnGSk9aaLosDroi2QDrlOfQ tySequence__UnGSk9aaLosDroi2QDrlOfQ;
typedef struct tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA;
typedef struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA tyTuple__q13Zt16VkCqu6Zg5jWqwHA;
typedef struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA tyTuple__aWN9bNzF9bubXNJV9ciomgpfA;
typedef struct tySequence__m4PVWjcAAjfxlwJxLkKn8A tySequence__m4PVWjcAAjfxlwJxLkKn8A;
typedef struct tyTuple__RWXAsQlFoGYyEQZp1G65sg tyTuple__RWXAsQlFoGYyEQZp1G65sg;
typedef struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg;
typedef struct tyTuple__RmGJuqOgEaHckHndh0LEsw tyTuple__RmGJuqOgEaHckHndh0LEsw;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__J4cxakKjhKxTIJR9bojMmXw tyTuple__J4cxakKjhKxTIJR9bojMmXw;
typedef struct tySequence__i89c5kdtWKzK3OEiI81pkkw tySequence__i89c5kdtWKzK3OEiI81pkkw;
typedef struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A;
typedef struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ;
typedef struct tySequence__GR8qmV1kNRcoQ2g76VFy3A tySequence__GR8qmV1kNRcoQ2g76VFy3A;
typedef struct tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg;
typedef struct tyTuple__a7QginWFapakKbWJBJ2vfA tyTuple__a7QginWFapakKbWJBJ2vfA;
typedef struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__kbX6x85REySUrk9auORL0vw tyTuple__kbX6x85REySUrk9auORL0vw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g;
typedef struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q;
typedef struct tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A;
typedef struct tyTuple__nF9cH4hinXgGEUwO4G2bshw tyTuple__nF9cH4hinXgGEUwO4G2bshw;
typedef struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA;
typedef struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__PsEhl3dzznmmJiLAuIXZOg tyTuple__PsEhl3dzznmmJiLAuIXZOg;
typedef struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w;
typedef struct tyTuple__Db8CrQifKGIsKc3w71w7Lw tyTuple__Db8CrQifKGIsKc3w71w7Lw;
typedef struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg;
typedef struct tySequence__lo3S1lKyiPLhGGB9cBawd6A tySequence__lo3S1lKyiPLhGGB9cBawd6A;
typedef struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ;
typedef struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw tyTuple__FEYH9alRJhHD0uTKF2vnIqw;
typedef struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA;
typedef struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA;
typedef struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw;
typedef struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg tyTuple__VUJ5Hjm4tKAResBsRHJvYg;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU32 tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw {
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
} _kind_4;
struct {tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
} _kind_5;
struct {tySequence__IeU9azYSNIK3V9b36Ir6NZcw* sons;
} _kind_6;
};
};
struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg {
NI id;
NimStringDesc* s;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* next;
NI h;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw {
NI elems;
NI counter;
NI max;
tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* head;
tySequence__q9cq1Li6c1nMjHpacEbCj0g* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA {
tySequence__ijtae5OneaLys0hN9alAicA* data;
NI counter;
};
struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w {
tySequence__SerjNoUujW2dUouVBrJiCw* data;
NI counter;
};
struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA {
tySequence__K9agbtcb0qPZuSJFXB9cTe6g* data;
NI counter;
};
typedef tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyArray__46hjIasL27aUz9c7kgtWooQ[5];
struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg {
tySequence__m88qdML9cQOuqGAQn6XWL1A* data;
NI counter;
};
struct tyObject_Table__1hIWbTQWYT4BmhdESze57A {
tySequence__naEbXEp9b9aiW1zXJorqf9cXQ* data;
NI counter;
};
struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
typedef NU8 tyEnum_TBackend__zoooocqvga73vZuhGAAy6A;
typedef NU8 tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w;
typedef NU8 tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ;
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU64 tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
};
struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw {
NI counter;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* data;
};
struct tyObject_Table__imojfg883tkWsWJwyshGqQ {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA {
tySequence__KgiZ29chkJAD01p9aLRB32qw* data;
NI counter;
};
struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A {
tySequence__rkYRZrbHVYL3nhXlQW3K9bw* data;
NI counter;
};
typedef tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg[65];
struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ {
tySequence__YmPd0eWfcTfrVYrthlXPYA* data;
NI counter;
};
struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, tyProc__I6rzVhdiYtUh7jwWJQoeyw) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__EQOAUyRkp9c3eeiGlHvCThA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q {
tySequence__Hz5SYwQU29b9aFLt09blvVQPg* data;
NI counter;
};
struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg {
tySequence__3G9aA9cLXaPxuRxMKm3anacQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__1CO5eEh25fBKUWGagpikwg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
typedef N_NIMCALL_PTR(void, tyProc__VcUg5jOhttLagdxUmVN8Tg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__XOkru1xuh2bHzmkw1UYzLA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* formal, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* actual);
struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opNot;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opContains;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLe;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLt;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAnd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opOr;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opIsNil;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opEq;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAdd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opSub;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opMul;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opDiv;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLen;
};
struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg {
tySequence__RNhZxf20g9beyq5VBOGxhDg* ifaces;
tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* packed_0;
tySequence__lFbCtu5P2Kf7YDYtGjkxAQ* encoders;
tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA typeInstCache;
tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w procInstCache;
tyArray__46hjIasL27aUz9c7kgtWooQ attachedOps;
tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg methodsPerType;
tyObject_Table__1hIWbTQWYT4BmhdESze57A enumToStringProcs;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw emittedTypeInfo;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA startupPackedConfig;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw deps;
tyObject_Table__imojfg883tkWsWJwyshGqQ importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__BCPh85PHtwxox9bv7NLFrlg inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* usageSym;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* owners;
tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA suggestSymbols;
tyObject_Table__LM44poVdVEn4Mo4N4L8c3A suggestErrors;
tySequence__IRFEb1e9bxgbJLuB5xrdZsQ* methods;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* systemModule;
tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg sysTypes;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw compilerprocs;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw exposed;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageTypes;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* emptyNode;
tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ canonTypes;
tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw symBodyHashes;
tyProc__I6rzVhdiYtUh7jwWJQoeyw importModuleCallback;
tyProc__EQOAUyRkp9c3eeiGlHvCThA includeFileCallback;
tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q cacheSeqs;
tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g cacheCounters;
tyObject_Table__R7JnJQEipxxOlJWXQz7jWg cacheTables;
tySequence__bPFv6ypvvCX2A9a9al8utL2Q* passes;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinition;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinitionResolveForward;
tyProc__1CO5eEh25fBKUWGagpikwg onUsage;
tySequence__IeU9azYSNIK3V9b36Ir6NZcw* globalDestructors;
tyProc__VcUg5jOhttLagdxUmVN8Tg strongSemCheck;
tyProc__XOkru1xuh2bHzmkw1UYzLA compatibleProps;
tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg operators;
};
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA {
  RootObj Sup;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg itemId;
};
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU16 tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag;
typedef NU64 tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU8 tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw;
typedef NU8 tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw {
tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k;
tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ storage;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
};
struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
union{
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* gcUnsafetyReason;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* transformedBody;
} _kind_1;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* guard;
NI bitsize;
NI alignment;
} _kind_2;
};
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* annex;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constraint;
};
typedef NU8 tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ;
typedef NU8 tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
struct tyTuple__D9cr9aW4733sg56WAiSRpttQ {
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw Field0;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw Field1;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA {
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* pnode;
NI id;
NI idx;
NI lowLink;
NIM_BOOL onStack;
tySequence__vAEg9bb6P9cAvzrQae7aeKyA* kids;
NI hAQ;
NI hIS;
NI hB;
NI hCmd;
};
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
typedef NU tyArray__cC4ce9cdvDKtIpar5g9cDejA[16];
struct tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg {
tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* next;
NI key;
tyArray__cC4ce9cdvDKtIpar5g9cDejA bits;
};
typedef struct {
N_NIMCALL_PTR(NI, ClP_0) (tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA* x, tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA* y, void* ClE_0);
void* ClE_0;
} tyProc__YRIBfnKx4fhbilJmrYB0MA;
typedef NU8 tyEnum_SortOrder__TcYjciSJ3jKUT4ygglumjg;
typedef N_CLOSURE_PTR(NI, TM__k9axqyY7R0TmDVutx9brQukQ_9) (tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA* x, tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA* y, void* ClE_0);
struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* converters;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* patterns;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* pureEnums;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interf;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interfHidden;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* uniqueName;
};
typedef NU8 tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg;
struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg {
tySequence__4Murtwnm0Fyc7F9acrytEXw* nodes;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ;
struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ {
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw {
tySequence__IHUFRsFxZNv7YydiUO2esQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag {
NimStringDesc* definedSymbols;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA moduleFlags;
tySequence__PXIzfWocnrafGz5p3CP5LA* includes;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* imports;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg toReplay;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg topLevel;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg bodies;
tySequence__b89aLriiJnVTD186H6zNIgg* exports;
tySequence__b89aLriiJnVTD186H6zNIgg* hidden;
tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw* reexports;
tySequence__b89aLriiJnVTD186H6zNIgg* compilerProcs;
tySequence__48JTohSgTy339bRxHzUD8KA* converters;
tySequence__48JTohSgTy339bRxHzUD8KA* methods;
tySequence__48JTohSgTy339bRxHzUD8KA* trmacros;
tySequence__48JTohSgTy339bRxHzUD8KA* pureEnums;
tySequence__QnmOtn1Iv4LvxOXoMn8Rbg* macroUsages;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* typeInstCache;
tySequence__qy6Iwdy00wN560qud54HTg* procInstCache;
tySequence__k67v9bwvvQDmS1ynyGGUbeQ* attachedOps;
tySequence__cLsClAAfd0MKkoBQVyvdvw* methodsPerType;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* enumToStringProcs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* emittedTypeInfo;
tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ backendFlags;
tySequence__q9bTuOB0JXh1iZ3CSGdRLbg* syms;
tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw* types;
tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ strings;
tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw numbers;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA cfg;
};
struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ {
tySequence__C3r8jsj9chA4sIlYfDN5aDw* data;
NI counter;
};
struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg {
tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg status;
NIM_BOOL symsInit;
NIM_BOOL typesInit;
NIM_BOOL loadedButAliveSetChanged;
tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag fromDisk;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* syms;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* types;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ iface;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ ifaceHidden;
};
struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ {
tySequence__9cnx3zXnWzeclW8Ko4oUgAQ* data;
NI counter;
};
struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ {
NI32 thisModule;
NI32 lastFile;
NU32 lastLit;
tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ filenames;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* pendingTypes;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* pendingSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw typeMarker;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw symMarker;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
};
struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ {
NU32 module;
NI32 item;
};
struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg {
NI module;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ packed_0;
};
struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
};
struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__dlD6tEGzYLLpKVq3XwuFlA* Field2;
};
struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q {
NI module;
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg sym;
tySequence__UnGSk9aaLosDroi2QDrlOfQ* concreteTypes;
tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA* inst;
};
struct tyTuple__rZZA0skon1OsHdiEvT8RZQ {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__6OFCSvqRaxyEgUqWtnZSlw* Field2;
};
struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field2;
};
struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
};
struct tyTuple__RWXAsQlFoGYyEQZp1G65sg {
NI Field0;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field1;
};
struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__m4PVWjcAAjfxlwJxLkKn8A* Field2;
};
struct tyTuple__RmGJuqOgEaHckHndh0LEsw {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field2;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
};
struct tyTuple__J4cxakKjhKxTIJR9bojMmXw {
NI Field0;
NI32 Field1;
tySequence__i89c5kdtWKzK3OEiI81pkkw* Field2;
};
struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ {
NI Field0;
NI32 Field1;
tySequence__GR8qmV1kNRcoQ2g76VFy3A* Field2;
};
struct tyTuple__a7QginWFapakKbWJBJ2vfA {
tySequence__ed0C0uAUZPhvw3RAc5hfYg* Field0;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field1;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__kbX6x85REySUrk9auORL0vw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q {
tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A* root;
NI entries;
};
struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q Field2;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw*, tyProc__kqPx9c4py2HW6KcFMhNvxtg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__9c6qRjwy7Es8UkDTIUwAfFA) (tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__mv4BsRs5VEnhcxzV6pQU5w) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
struct tyTuple__nF9cH4hinXgGEUwO4G2bshw {
tyProc__kqPx9c4py2HW6KcFMhNvxtg Field0;
tyProc__9c6qRjwy7Es8UkDTIUwAfFA Field1;
tyProc__mv4BsRs5VEnhcxzV6pQU5w Field2;
NIM_BOOL Field3;
};
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
NU32 Field0;
NimStringDesc* Field1;
};
struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA {
NU16 line;
NI16 col;
NU32 file;
};
struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA {
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
NI32 operand;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeId_0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
};
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
NU32 Field0;
NI32 Field1;
};
struct tyTuple__PsEhl3dzznmmJiLAuIXZOg {
NU32 Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA Field1;
};
struct tyTuple__Db8CrQifKGIsKc3w71w7Lw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ key;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* concreteTypes;
};
typedef NU8 tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ;
struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ {
tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
NI Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
typedef NU8 tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ;
struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA {
tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ kind;
NIM_BOOL generated;
NIM_BOOL isOverriden;
NU32 name;
NI32 path;
};
struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA {
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
NU32 name;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typ;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
NI32 ast;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ guard;
NI bitsize;
NI alignment;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
NU32 externalName;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw locFlags;
tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA annex;
NI32 constraint;
};
typedef NU8 tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg;
typedef NU8 tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg;
typedef NU64 tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw {
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* types;
NI32 n;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeInst;
NI32 nonUniqueId;
};
struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg {
NI Field0;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* Field1;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* Field2;
};
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
NI Field0;
NI32 Field1;
NU32 Field2;
};
struct tySequence__fZ9aerq6GRgd1Id9b1cf7NuA {
  TGenericSeq Sup;
  tyTuple__D9cr9aW4733sg56WAiSRpttQ data[SEQ_DECL_SIZE];
};
struct tySequence__vAEg9bb6P9cAvzrQae7aeKyA {
  TGenericSeq Sup;
  tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA* data[SEQ_DECL_SIZE];
};
struct tySequence__AT39bF59bUK7pfvl9asfwzQ6A {
  TGenericSeq Sup;
  tySequence__vAEg9bb6P9cAvzrQae7aeKyA* data[SEQ_DECL_SIZE];
};
struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw {
  TGenericSeq Sup;
  tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* data[SEQ_DECL_SIZE];
};
struct tySequence__q9cq1Li6c1nMjHpacEbCj0g {
  TGenericSeq Sup;
  tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* data[SEQ_DECL_SIZE];
};
struct tySequence__RNhZxf20g9beyq5VBOGxhDg {
  TGenericSeq Sup;
  tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ data[SEQ_DECL_SIZE];
};
struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ {
  TGenericSeq Sup;
  tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg data[SEQ_DECL_SIZE];
};
struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ {
  TGenericSeq Sup;
  tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ data[SEQ_DECL_SIZE];
};
struct tySequence__dlD6tEGzYLLpKVq3XwuFlA {
  TGenericSeq Sup;
  tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ data[SEQ_DECL_SIZE];
};
struct tySequence__ijtae5OneaLys0hN9alAicA {
  TGenericSeq Sup;
  tyTuple__UluY8x0Nj6cp9b0o88wJ0lg data[SEQ_DECL_SIZE];
};
struct tySequence__6OFCSvqRaxyEgUqWtnZSlw {
  TGenericSeq Sup;
  tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q data[SEQ_DECL_SIZE];
};
struct tySequence__SerjNoUujW2dUouVBrJiCw {
  TGenericSeq Sup;
  tyTuple__rZZA0skon1OsHdiEvT8RZQ data[SEQ_DECL_SIZE];
};
struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g {
  TGenericSeq Sup;
  tyTuple__q13Zt16VkCqu6Zg5jWqwHA data[SEQ_DECL_SIZE];
};
struct tySequence__m4PVWjcAAjfxlwJxLkKn8A {
  TGenericSeq Sup;
  tyTuple__RWXAsQlFoGYyEQZp1G65sg data[SEQ_DECL_SIZE];
};
struct tySequence__m88qdML9cQOuqGAQn6XWL1A {
  TGenericSeq Sup;
  tyTuple__aWN9bNzF9bubXNJV9ciomgpfA data[SEQ_DECL_SIZE];
};
struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ {
  TGenericSeq Sup;
  tyTuple__RmGJuqOgEaHckHndh0LEsw data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__ed0C0uAUZPhvw3RAc5hfYg {
  TGenericSeq Sup;
  tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__i89c5kdtWKzK3OEiI81pkkw {
  TGenericSeq Sup;
  tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A data[SEQ_DECL_SIZE];
};
struct tySequence__KgiZ29chkJAD01p9aLRB32qw {
  TGenericSeq Sup;
  tyTuple__J4cxakKjhKxTIJR9bojMmXw data[SEQ_DECL_SIZE];
};
struct tySequence__GR8qmV1kNRcoQ2g76VFy3A {
  TGenericSeq Sup;
  tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* data[SEQ_DECL_SIZE];
};
struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw {
  TGenericSeq Sup;
  tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ data[SEQ_DECL_SIZE];
};
struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ {
  TGenericSeq Sup;
  tyTuple__a7QginWFapakKbWJBJ2vfA data[SEQ_DECL_SIZE];
};
struct tySequence__YmPd0eWfcTfrVYrthlXPYA {
  TGenericSeq Sup;
  tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg {
  TGenericSeq Sup;
  tyTuple__kbX6x85REySUrk9auORL0vw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ {
  TGenericSeq Sup;
  tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g data[SEQ_DECL_SIZE];
};
struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q {
  TGenericSeq Sup;
  tyTuple__nF9cH4hinXgGEUwO4G2bshw data[SEQ_DECL_SIZE];
};
struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g {
  TGenericSeq Sup;
  tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg data[SEQ_DECL_SIZE];
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  TGenericSeq Sup;
  tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE];
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  TGenericSeq Sup;
  NU32 data[SEQ_DECL_SIZE];
};
struct tySequence__4Murtwnm0Fyc7F9acrytEXw {
  TGenericSeq Sup;
  tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA data[SEQ_DECL_SIZE];
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  TGenericSeq Sup;
  tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE];
};
struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw {
  TGenericSeq Sup;
  tyTuple__PsEhl3dzznmmJiLAuIXZOg data[SEQ_DECL_SIZE];
};
struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg {
  TGenericSeq Sup;
  tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w data[SEQ_DECL_SIZE];
};
struct tySequence__oKtVqsc9bQVCNyrijELM4OQ {
  TGenericSeq Sup;
  tyTuple__Db8CrQifKGIsKc3w71w7Lw data[SEQ_DECL_SIZE];
};
struct tySequence__qy6Iwdy00wN560qud54HTg {
  TGenericSeq Sup;
  tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg data[SEQ_DECL_SIZE];
};
struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ {
  TGenericSeq Sup;
  tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ data[SEQ_DECL_SIZE];
};
struct tySequence__cLsClAAfd0MKkoBQVyvdvw {
  TGenericSeq Sup;
  tyTuple__FEYH9alRJhHD0uTKF2vnIqw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg {
  TGenericSeq Sup;
  tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA data[SEQ_DECL_SIZE];
};
struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw {
  TGenericSeq Sup;
  tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw data[SEQ_DECL_SIZE];
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  TGenericSeq Sup;
  NI64 data[SEQ_DECL_SIZE];
};
struct tySequence__vKogasEnJSPhbQmA8r4Y9aA {
  TGenericSeq Sup;
  tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* data[SEQ_DECL_SIZE];
};
struct tySequence__lo3S1lKyiPLhGGB9cBawd6A {
  TGenericSeq Sup;
  tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ data[SEQ_DECL_SIZE];
};
struct tySequence__C3r8jsj9chA4sIlYfDN5aDw {
  TGenericSeq Sup;
  tyTuple__VUJ5Hjm4tKAResBsRHJvYg data[SEQ_DECL_SIZE];
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  TGenericSeq Sup;
  tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE];
};
struct tySequence__UnGSk9aaLosDroi2QDrlOfQ {
  TGenericSeq Sup;
  tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg data[SEQ_DECL_SIZE];
};
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasForbiddenPragma__reorder_925)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_238)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result);
N_LIB_PRIVATE N_NIMCALL(void, initPackedSet__pureZcollectionsZintsets_16)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFullPath__msgs_548)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, splitSections__reorder_335)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNodeI__ast_3320)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNode__ast_3289)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_4798)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* father, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* son);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, expandIncludes__reorder_245)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NimStringDesc* modulePath, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* includedFiles);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasIncludes__reorder_232)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NI32, checkModuleName__modulepaths_21)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL doLocalError);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsOrIncl__astalgo_402)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_1128)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, NimStringDesc* arg, tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatSingleElem)(NimStringDesc* formatstr, NimStringDesc* a);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toMsgFilename__msgs_612)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, includeModule__reorder_240)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, NI32 fileIdx);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, parseFile__syntaxes_217)(NI32 fileIdx, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config);
N_LIB_PRIVATE N_NIMCALL(void, addDep__modulegraphs_9601)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 dep);
N_LIB_PRIVATE N_NIMCALL(void, addIncludeDep__modulegraphs_9612)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NI32 module, NI32 includeFile);
N_LIB_PRIVATE N_NIMCALL(void, excl__reorder_273)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
N_LIB_PRIVATE N_NIMCALL(tySequence__fZ9aerq6GRgd1Id9b1cf7NuA*, newSeq__reorder_951)(NI len);
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tySequence__fZ9aerq6GRgd1Id9b1cf7NuA)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void, computeDeps__reorder_108)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* declares, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* uses, NIM_BOOL topLevel);
N_LIB_PRIVATE N_NIMCALL(void, addDecl__reorder_88)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* declares);
N_LIB_PRIVATE N_NIMCALL(void, incl__pureZcollectionsZintsets_55)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg*, accQuoted__reorder_73)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg*, getPIdent__ast_3060)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a);
static N_INLINE(NIM_BOOL, eqeq___idents_229)(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* a, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* b);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg*, getIdent__idents_152)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* ic, NimStringDesc* identifier);
N_LIB_PRIVATE N_NIMCALL(tySequence__vAEg9bb6P9cAvzrQae7aeKyA*, buildGraph__reorder_760)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySequence__fZ9aerq6GRgd1Id9b1cf7NuA* deps);
N_LIB_PRIVATE N_NIMCALL(void*, nimNewSeqOfCap)(TNimType* typ, NI cap);
static N_NIMCALL(void, Marker_tyRef__Si6SFYrfWmFpQSJlvZ5FVA)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__vAEg9bb6P9cAvzrQae7aeKyA)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA*, newDepN__reorder_26)(NI id, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* pnode);
N_LIB_PRIVATE N_NOINLINE(void*, newObj)(TNimType* typ, NI size);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5302)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5264)(void* usr);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(void, decRef__system_5309)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5307)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5258)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(void, nimGCunrefRC1)(void* p);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasBody__reorder_740)(tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasBody__reorder_727)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasCommand__reorder_697)(tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasCommand__reorder_693)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasImportStmt__reorder_687)(tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasImportStmt__reorder_683)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasAccQuotedDef__reorder_721)(tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasAccQuotedDef__reorder_716)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasAccQuoted__reorder_703)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, intersects__reorder_746)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s1, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__astalgo_3489)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
N_LIB_PRIVATE N_NIMCALL(tySequence__AT39bF59bUK7pfvl9asfwzQ6A*, getStrongComponents__reorder_916)(tySequence__vAEg9bb6P9cAvzrQae7aeKyA** g);
N_LIB_PRIVATE N_NIMCALL(void, strongConnect__reorder_837)(tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA** v, NI* idx, tySequence__vAEg9bb6P9cAvzrQae7aeKyA** s, tySequence__AT39bF59bUK7pfvl9asfwzQ6A** res);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(tySequence__vAEg9bb6P9cAvzrQae7aeKyA*, newSeq__reorder_478)(NI len);
static N_INLINE(tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA*, pop__reorder_877)(tySequence__vAEg9bb6P9cAvzrQae7aeKyA** s);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
static N_NIMCALL(void, Marker_tySequence__AT39bF59bUK7pfvl9asfwzQ6A)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void, genericSeqAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(void, mergeSections__reorder_404)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tySequence__AT39bF59bUK7pfvl9asfwzQ6A* comps, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* res);
N_LIB_PRIVATE N_NIMCALL(tySequence__vAEg9bb6P9cAvzrQae7aeKyA*, sorted__reorder_466)(tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA** a, NI aLen_0, tyProc__YRIBfnKx4fhbilJmrYB0MA cmp, tyEnum_SortOrder__TcYjciSJ3jKUT4ygglumjg order);
N_LIB_PRIVATE N_NIMCALL(NI, colonanonymous___reorder_448)(tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA* xX60gensym51_, tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA* yX60gensym51_);
N_LIB_PRIVATE N_NIMCALL(NI, cmp__system_7445)(NI x, NI y);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, haveSameKind__reorder_367)(tySequence__vAEg9bb6P9cAvzrQae7aeKyA* dns);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
STRING_LITERAL(TM__k9axqyY7R0TmDVutx9brQukQ_2, "push", 4);
STRING_LITERAL(TM__k9axqyY7R0TmDVutx9brQukQ_3, "recursive dependency: \'$1\'", 26);
STRING_LITERAL(TM__k9axqyY7R0TmDVutx9brQukQ_5, "/home/runner/work/nightlies/nightlies/nim/compiler/reorder.nim", 62);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__k9axqyY7R0TmDVutx9brQukQ_4 = {((NimStringDesc*) &TM__k9axqyY7R0TmDVutx9brQukQ_5),
((NI) 132),
((NI) 22)}
;
N_LIB_PRIVATE TNimType NTILintset_intsetT__D9cr9aW4733sg56WAiSRpttQ_;
extern TNimType NTIpackedset__THXDbzJSs2hcC9a33en2pdw_;
N_LIB_PRIVATE TNimType NTIseqLLintset_intsetTT__fZ9aerq6GRgd1Id9b1cf7NuA_;
STRING_LITERAL(TM__k9axqyY7R0TmDVutx9brQukQ_7, "pragma", 6);
N_LIB_PRIVATE TNimType NTIdepn58objecttype__T7a6etQXL0CBg8BjsbsXpA_;
extern TNimType NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_;
extern TNimType NTIint__rR5Bzr1D5krxoo1NcNyeMA_;
extern TNimType NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_;
N_LIB_PRIVATE TNimType NTIdepn__Si6SFYrfWmFpQSJlvZ5FVA_;
N_LIB_PRIVATE TNimType NTIseqLdepnT__vAEg9bb6P9cAvzrQae7aeKyA_;
N_LIB_PRIVATE TNimType NTIseqLseqLdepnTT__AT39bF59bUK7pfvl9asfwzQ6A_;
STRING_LITERAL(TM__k9axqyY7R0TmDVutx9brQukQ_10, "Circular dependency detected. `codeReordering` pragma may not be able to reorder some nodes properly", 100);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__k9axqyY7R0TmDVutx9brQukQ_11 = {((NimStringDesc*) &TM__k9axqyY7R0TmDVutx9brQukQ_5),
((NI) 208),
((NI) 15)}
;
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5211;
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 0) && (*n).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__ast_3155(n);
	}
	LA1_: ;
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__system_1741(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasForbiddenPragma__reorder_925)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a;
		a = NIM_NIL;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_3148(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					a = (*n)._kind_6.sons->data[i];
					{
						NIM_BOOL T7_;
						NIM_BOOL T8_;
						T7_ = (NIM_BOOL)0;
						T8_ = (NIM_BOOL)0;
						T8_ = ((*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 90));
						if (!(T8_)) goto LA9_;
						T8_ = ((*(*a)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2));
						LA9_: ;
						T7_ = T8_;
						if (!(T7_)) goto LA10_;
						T7_ = eqStrings((*(*(*a)._kind_6.sons->data[((NI) 0)])._kind_5.ident).s, ((NimStringDesc*) &TM__k9axqyY7R0TmDVutx9brQukQ_2));
						LA10_: ;
						if (!T7_) goto LA11_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
					LA11_: ;
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_238)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result) {
	initPackedSet__pureZcollectionsZintsets_16(Result);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, splitSections__reorder_335)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	result = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115), (*n).info);
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a;
		a = NIM_NIL;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_3148(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					a = (*n)._kind_6.sons->data[i];
					{
						NIM_BOOL T7_;
						NI T9_;
						T7_ = (NIM_BOOL)0;
						T7_ = ((*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 98) || (*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 101));
						if (!(T7_)) goto LA8_;
						T9_ = (NI)0;
						T9_ = len__ast_3155(a);
						T7_ = (((NI) 1) < T9_);
						LA8_: ;
						if (!T7_) goto LA10_;
						{
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b;
							b = NIM_NIL;
							{
								NI i_3;
								NI colontmp__2;
								NI i_4;
								i_3 = (NI)0;
								colontmp__2 = (NI)0;
								colontmp__2 = safeLen__ast_3148(a);
								i_4 = ((NI) 0);
								{
									while (1) {
										tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* s;
										if (!(i_4 < colontmp__2)) goto LA15;
										i_3 = i_4;
										b = (*a)._kind_6.sons->data[i_3];
										s = newNode__ast_3289((*a).kind);
										(*s).info = (*b).info;
										add__ast_4798(s, b);
										add__ast_4798(result, s);
										i_4 += ((NI) 1);
									} LA15: ;
								}
							}
						}
					}
					goto LA5_;
					LA10_: ;
					{
						add__ast_4798(result, a);
					}
					LA5_: ;
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasIncludes__reorder_232)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a;
		a = NIM_NIL;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_3148(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					a = (*n)._kind_6.sons->data[i];
					{
						if (!((*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 121))) goto LA7_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
					LA7_: ;
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, includeModule__reorder_240)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, NI32 fileIdx) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	result = parseFile__syntaxes_217(fileIdx, (*graph).cache, (*graph).config);
	addDep__modulegraphs_9601(graph, s, fileIdx);
	addIncludeDep__modulegraphs_9612(graph, ((NI32) ((*s).position)), fileIdx);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, expandIncludes__reorder_245)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NimStringDesc* modulePath, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* includedFiles) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
{	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = hasIncludes__reorder_232(n);
		if (!!(T3_)) goto LA4_;
		result = n;
		goto BeforeRet_;
	}
	LA4_: ;
	result = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115), (*n).info);
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a;
		a = NIM_NIL;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_3148(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA9;
					i = i_2;
					a = (*n)._kind_6.sons->data[i];
					{
						if (!((*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 121))) goto LA12_;
						{
							NI i_3;
							NI colontmp__2;
							NI i_4;
							i_3 = (NI)0;
							colontmp__2 = (NI)0;
							colontmp__2 = len__ast_3155(a);
							i_4 = ((NI) 0);
							{
								while (1) {
									NI32 f;
									if (!(i_4 < colontmp__2)) goto LA16;
									i_3 = i_4;
									f = checkModuleName__modulepaths_21((*graph).config, (*a)._kind_6.sons->data[i_3], NIM_TRUE);
									{
										if (!!((f == ((NI32) -1)))) goto LA19_;
										{
											NIM_BOOL T23_;
											NimStringDesc* T26_;
											NimStringDesc* T27_;
											T23_ = (NIM_BOOL)0;
											T23_ = containsOrIncl__astalgo_402(includedFiles, ((NI) (f)));
											if (!T23_) goto LA24_;
											T26_ = NIM_NIL;
											T26_ = toMsgFilename__msgs_612((*graph).config, f);
											T27_ = NIM_NIL;
											T27_ = nsuFormatSingleElem(((NimStringDesc*) &TM__k9axqyY7R0TmDVutx9brQukQ_3), T26_);
											liMessage__msgs_1128((*graph).config, (*a).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T27_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__k9axqyY7R0TmDVutx9brQukQ_4, NIM_FALSE);
										}
										goto LA21_;
										LA24_: ;
										{
											tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* nn;
											tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* nnn;
											nn = includeModule__reorder_240(graph, module, f);
											nnn = expandIncludes__reorder_245(graph, module, nn, modulePath, includedFiles);
											excl__reorder_273(includedFiles, ((NI) (f)));
											{
												tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b;
												b = NIM_NIL;
												{
													NI i_5;
													NI colontmp__3;
													NI i_6;
													i_5 = (NI)0;
													colontmp__3 = (NI)0;
													colontmp__3 = safeLen__ast_3148(nnn);
													i_6 = ((NI) 0);
													{
														while (1) {
															if (!(i_6 < colontmp__3)) goto LA32;
															i_5 = i_6;
															b = (*nnn)._kind_6.sons->data[i_5];
															add__ast_4798(result, b);
															i_6 += ((NI) 1);
														} LA32: ;
													}
												}
											}
										}
										LA21_: ;
									}
									LA19_: ;
									i_4 += ((NI) 1);
								} LA16: ;
							}
						}
					}
					goto LA10_;
					LA12_: ;
					{
						add__ast_4798(result, a);
					}
					LA10_: ;
					i_2 += ((NI) 1);
				} LA9: ;
			}
		}
	}
	}BeforeRet_: ;
	return result;
}
static N_NIMCALL(void, Marker_tySequence__fZ9aerq6GRgd1Id9b1cf7NuA)(void* p, NI op) {
	tySequence__fZ9aerq6GRgd1Id9b1cf7NuA* a;
	NI T1_;
	NI T2_;
	NI T3_;
	a = (tySequence__fZ9aerq6GRgd1Id9b1cf7NuA*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field0.head, op);
	nimGCvisit((void*)a->data[T1_].Field0.data, op);
	T2_ = (NI)0;
	nimGCvisit((void*)a->data[T1_].Field1.head, op);
	nimGCvisit((void*)a->data[T1_].Field1.data, op);
	T3_ = (NI)0;
	}
}
static N_INLINE(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg*, getPIdent__ast_3060)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a) {
	tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* result;
	result = NIM_NIL;
	switch ((*a).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		result = (*(*a)._kind_4.sym).name;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2):
	{
		result = (*a)._kind_5.ident;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 57):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 56):
	{
		result = (*(*(*a)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name;
	}
	break;
	default:
	{
		result = ((tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg*) NIM_NIL);
	}
	break;
	}
	return result;
}
static N_INLINE(NIM_BOOL, eqeq___idents_229)(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* a, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* b) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (a == 0);
		if (T3_) goto LA4_;
		T3_ = (b == 0);
		LA4_: ;
		if (!T3_) goto LA5_;
		result = (a == b);
	}
	goto LA1_;
	LA5_: ;
	{
		result = ((*a).id == (*b).id);
	}
	LA1_: ;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg*, accQuoted__reorder_73)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* result;
	NimStringDesc* id;
	result = NIM_NIL;
	id = ((NimStringDesc*) NIM_NIL);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				ident = getPIdent__ast_3060((*n)._kind_6.sons->data[i]);
				{
					NIM_BOOL T6_;
					T6_ = (NIM_BOOL)0;
					T6_ = eqeq___idents_229(ident, ((tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg*) NIM_NIL));
					if (!!(T6_)) goto LA7_;
					id = resizeString(id, ((*ident).s ? (*ident).s->Sup.len : 0) + 0);
appendString(id, (*ident).s);
				}
				LA7_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	result = getIdent__idents_152(cache, id);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addDecl__reorder_88)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* declares) {
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 31):
	{
		addDecl__reorder_88(cache, (*n)._kind_6.sons->data[((NI) 1)], declares);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 43):
	{
		addDecl__reorder_88(cache, (*n)._kind_6.sons->data[((NI) 0)], declares);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2):
	{
		incl__pureZcollectionsZintsets_55(declares, (*(*n)._kind_5.ident).id);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		incl__pureZcollectionsZintsets_55(declares, (*(*(*n)._kind_4.sym).name).id);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 53):
	{
		tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* a;
		a = accQuoted__reorder_73(cache, n);
		incl__pureZcollectionsZintsets_55(declares, (*a).id);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 151):
	{
		addDecl__reorder_88(cache, (*n)._kind_6.sons->data[((NI) 0)], declares);
	}
	break;
	default:
	{
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, computeDeps__reorder_108)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* declares, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* uses, NIM_BOOL topLevel) {
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 51) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 52):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 82):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 83):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 79) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 81):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 84):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 159):
	{
		{
			if (!topLevel) goto LA4_;
			addDecl__reorder_88(cache, (*n)._kind_6.sons->data[((NI) 0)], declares);
		}
		LA4_: ;
		{
			NI i;
			NI res;
			i = (NI)0;
			res = ((NI) 1);
			{
				while (1) {
					if (!(res <= ((NI) 6))) goto LA8;
					i = res;
					computeDeps__reorder_108(cache, (*n)._kind_6.sons->data[i], declares, uses, NIM_FALSE);
					res += ((NI) 1);
				} LA8: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 100):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 99):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 124):
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a;
			a = NIM_NIL;
			{
				NI i_2;
				NI colontmp_;
				NI i_3;
				i_2 = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_3148(n);
				i_3 = ((NI) 0);
				{
					while (1) {
						if (!(i_3 < colontmp_)) goto LA13;
						i_2 = i_3;
						a = (*n)._kind_6.sons->data[i_2];
						{
							if (!((*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 35) || (*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 36))) goto LA16_;
							{
								NI j;
								NI colontmp__2;
								NI T19_;
								NI i_4;
								j = (NI)0;
								colontmp__2 = (NI)0;
								T19_ = (NI)0;
								T19_ = len__ast_3155(a);
								colontmp__2 = (NI)(T19_ - ((NI) 2));
								i_4 = ((NI) 0);
								{
									while (1) {
										if (!(i_4 < colontmp__2)) goto LA21;
										j = i_4;
										{
											if (!topLevel) goto LA24_;
											addDecl__reorder_88(cache, (*a)._kind_6.sons->data[j], declares);
										}
										LA24_: ;
										i_4 += ((NI) 1);
									} LA21: ;
								}
							}
							{
								NI j_2;
								NI colontmp__3;
								NI colontmp__4;
								NI T27_;
								NI i_5;
								j_2 = (NI)0;
								colontmp__3 = (NI)0;
								colontmp__4 = (NI)0;
								T27_ = (NI)0;
								T27_ = len__ast_3155(a);
								colontmp__3 = (NI)(T27_ - ((NI) 2));
								colontmp__4 = len__ast_3155(a);
								i_5 = colontmp__3;
								{
									while (1) {
										if (!(i_5 < colontmp__4)) goto LA29;
										j_2 = i_5;
										computeDeps__reorder_108(cache, (*a)._kind_6.sons->data[j_2], declares, uses, NIM_FALSE);
										i_5 += ((NI) 1);
									} LA29: ;
								}
							}
						}
						LA16_: ;
						i_3 += ((NI) 1);
					} LA13: ;
				}
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 101):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 98):
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a_2;
			a_2 = NIM_NIL;
			{
				NI i_6;
				NI colontmp__5;
				NI i_7;
				i_6 = (NI)0;
				colontmp__5 = (NI)0;
				colontmp__5 = safeLen__ast_3148(n);
				i_7 = ((NI) 0);
				{
					while (1) {
						if (!(i_7 < colontmp__5)) goto LA34;
						i_6 = i_7;
						a_2 = (*n)._kind_6.sons->data[i_6];
						{
							NI T37_;
							T37_ = (NI)0;
							T37_ = len__ast_3155(a_2);
							if (!(((NI) 3) <= T37_)) goto LA38_;
							{
								if (!topLevel) goto LA42_;
								addDecl__reorder_88(cache, (*a_2)._kind_6.sons->data[((NI) 0)], declares);
							}
							LA42_: ;
							{
								NI i_8;
								NI colontmp__6;
								NI i_9;
								i_8 = (NI)0;
								colontmp__6 = (NI)0;
								colontmp__6 = len__ast_3155(a_2);
								i_9 = ((NI) 1);
								{
									while (1) {
										if (!(i_9 < colontmp__6)) goto LA46;
										i_8 = i_9;
										{
											if (!((*(*a_2)._kind_6.sons->data[i_8]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 150))) goto LA49_;
											{
												tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b;
												tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* colontmp__7;
												b = NIM_NIL;
												colontmp__7 = NIM_NIL;
												colontmp__7 = (*a_2)._kind_6.sons->data[i_8];
												{
													NI i_10;
													NI colontmp__8;
													NI i_11;
													i_10 = (NI)0;
													colontmp__8 = (NI)0;
													colontmp__8 = safeLen__ast_3148(colontmp__7);
													i_11 = ((NI) 0);
													{
														while (1) {
															if (!(i_11 < colontmp__8)) goto LA54;
															i_10 = i_11;
															b = (*colontmp__7)._kind_6.sons->data[i_10];
															{
																if (!topLevel) goto LA57_;
																addDecl__reorder_88(cache, b, declares);
															}
															LA57_: ;
															i_11 += ((NI) 1);
														} LA54: ;
													}
												}
											}
										}
										goto LA47_;
										LA49_: ;
										{
											computeDeps__reorder_108(cache, (*a_2)._kind_6.sons->data[i_8], declares, uses, NIM_FALSE);
										}
										LA47_: ;
										i_9 += ((NI) 1);
									} LA46: ;
								}
							}
						}
						LA38_: ;
						i_7 += ((NI) 1);
					} LA34: ;
				}
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 35):
	{
		{
			NI i_12;
			NI colontmp__9;
			NI i_13;
			i_12 = (NI)0;
			colontmp__9 = (NI)0;
			colontmp__9 = len__ast_3155(n);
			i_13 = ((NI) 1);
			{
				while (1) {
					if (!(i_13 < colontmp__9)) goto LA63;
					i_12 = i_13;
					computeDeps__reorder_108(cache, (*n)._kind_6.sons->data[i_12], declares, uses, NIM_FALSE);
					i_13 += ((NI) 1);
				} LA63: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2):
	{
		incl__pureZcollectionsZintsets_55(uses, (*(*n)._kind_5.ident).id);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		incl__pureZcollectionsZintsets_55(uses, (*(*(*n)._kind_4.sym).name).id);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 53):
	{
		tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T67_;
		T67_ = NIM_NIL;
		T67_ = accQuoted__reorder_73(cache, n);
		incl__pureZcollectionsZintsets_55(uses, (*T67_).id);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 57):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 56):
	{
		incl__pureZcollectionsZintsets_55(uses, (*(*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name).id);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 126):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 93):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 86):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 88):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 113):
	{
		{
			NI i_14;
			NI colontmp__10;
			NI i_15;
			i_14 = (NI)0;
			colontmp__10 = (NI)0;
			colontmp__10 = len__ast_3155(n);
			i_15 = ((NI) 0);
			{
				while (1) {
					if (!(i_15 < colontmp__10)) goto LA72;
					i_14 = i_15;
					computeDeps__reorder_108(cache, (*n)._kind_6.sons->data[i_14], declares, uses, topLevel);
					i_15 += ((NI) 1);
				} LA72: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 90):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a_3;
		a_3 = (*n)._kind_6.sons->data[((NI) 0)];
		{
			NIM_BOOL T76_;
			NIM_BOOL T77_;
			T76_ = (NIM_BOOL)0;
			T77_ = (NIM_BOOL)0;
			T77_ = ((*a_3).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34));
			if (!(T77_)) goto LA78_;
			T77_ = ((*(*a_3)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2));
			LA78_: ;
			T76_ = T77_;
			if (!(T76_)) goto LA79_;
			T76_ = eqStrings((*(*(*a_3)._kind_6.sons->data[((NI) 0)])._kind_5.ident).s, ((NimStringDesc*) &TM__k9axqyY7R0TmDVutx9brQukQ_7));
			LA79_: ;
			if (!T76_) goto LA80_;
			{
				if (!topLevel) goto LA84_;
				addDecl__reorder_88(cache, (*a_3)._kind_6.sons->data[((NI) 1)], declares);
			}
			LA84_: ;
		}
		goto LA74_;
		LA80_: ;
		{
			{
				NI i_16;
				NI colontmp__11;
				NI i_17;
				i_16 = (NI)0;
				colontmp__11 = (NI)0;
				colontmp__11 = safeLen__ast_3148(n);
				i_17 = ((NI) 0);
				{
					while (1) {
						if (!(i_17 < colontmp__11)) goto LA89;
						i_16 = i_17;
						computeDeps__reorder_108(cache, (*n)._kind_6.sons->data[i_16], declares, uses, NIM_FALSE);
						i_17 += ((NI) 1);
					} LA89: ;
				}
			}
		}
		LA74_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 123):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 122):
	{
	}
	break;
	default:
	{
		{
			NI i_18;
			NI colontmp__12;
			NI i_19;
			i_18 = (NI)0;
			colontmp__12 = (NI)0;
			colontmp__12 = safeLen__ast_3148(n);
			i_19 = ((NI) 0);
			{
				while (1) {
					if (!(i_19 < colontmp__12)) goto LA94;
					i_18 = i_19;
					computeDeps__reorder_108(cache, (*n)._kind_6.sons->data[i_18], declares, uses, NIM_FALSE);
					i_19 += ((NI) 1);
				} LA94: ;
			}
		}
	}
	break;
	}
}
static N_NIMCALL(void, Marker_tyRef__Si6SFYrfWmFpQSJlvZ5FVA)(void* p, NI op) {
	tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA* a;
	a = (tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA*)p;
	nimGCvisit((void*)(*a).pnode, op);
	nimGCvisit((void*)(*a).kids, op);
}
static N_NIMCALL(void, Marker_tySequence__vAEg9bb6P9cAvzrQae7aeKyA)(void* p, NI op) {
	tySequence__vAEg9bb6P9cAvzrQae7aeKyA* a;
	NI T1_;
	a = (tySequence__vAEg9bb6P9cAvzrQae7aeKyA*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_], op);
	}
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) + (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5302)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5264)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5307)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5258((&gch__system_5211.zct), c);
}
static N_INLINE(void, decRef__system_5309)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5307(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5264(src);
		incRef__system_5302(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5264((*dest));
		decRef__system_5309(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(void, nimGCunrefRC1)(void* p) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T1_;
	T1_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = usrToCell__system_5264(p);
	decRef__system_5309(T1_);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA*, newDepN__reorder_26)(NI id, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* pnode) {
	tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA* result;
	result = NIM_NIL;
	result = (tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA*) newObj((&NTIdepn__Si6SFYrfWmFpQSJlvZ5FVA_), sizeof(tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA));
	(*result).id = id;
	asgnRef((void**) (&(*result).pnode), pnode);
	(*result).idx = ((NI) -1);
	(*result).lowLink = ((NI) -1);
	(*result).onStack = NIM_FALSE;
	if ((*result).kids) { nimGCunrefRC1((*result).kids); (*result).kids = NIM_NIL; }
	(*result).hAQ = ((NI) -1);
	(*result).hIS = ((NI) -1);
	(*result).hB = ((NI) -1);
	(*result).hCmd = ((NI) -1);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasBody__reorder_727)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27):
	{
		result = NIM_TRUE;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 51) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 52):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 79) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 84):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 159):
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__ast_3155(n);
		result = ((*(*n)._kind_6.sons->data[(NI)(T3_ - ((NI) 1))]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115));
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 126):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 93):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 86):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 88):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 113):
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a;
			a = NIM_NIL;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_3148(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA8;
						i = i_2;
						a = (*n)._kind_6.sons->data[i];
						{
							NIM_BOOL T11_;
							T11_ = (NIM_BOOL)0;
							T11_ = hasBody__reorder_727(a);
							if (!T11_) goto LA12_;
							result = NIM_TRUE;
							goto BeforeRet_;
						}
						LA12_: ;
						i_2 += ((NI) 1);
					} LA8: ;
				}
			}
		}
	}
	break;
	default:
	{
		result = NIM_FALSE;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasBody__reorder_740)(tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA* n) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		NIM_BOOL T5_;
		if (!((*n).hB < ((NI) 0))) goto LA3_;
		T5_ = (NIM_BOOL)0;
		T5_ = hasBody__reorder_727((*n).pnode);
		(*n).hB = T5_;
	}
	LA3_: ;
	result = (((*n).hB) != 0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasCommand__reorder_693)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27):
	{
		result = NIM_TRUE;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 126):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 93):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 86):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 88):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 113):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 100):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 101):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 99):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 35):
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a;
			a = NIM_NIL;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_3148(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA6;
						i = i_2;
						a = (*n)._kind_6.sons->data[i];
						{
							NIM_BOOL T9_;
							T9_ = (NIM_BOOL)0;
							T9_ = hasCommand__reorder_693(a);
							if (!T9_) goto LA10_;
							result = NIM_TRUE;
							goto BeforeRet_;
						}
						LA10_: ;
						i_2 += ((NI) 1);
					} LA6: ;
				}
			}
		}
	}
	break;
	default:
	{
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasCommand__reorder_697)(tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA* n) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		NIM_BOOL T5_;
		if (!((*n).hCmd < ((NI) 0))) goto LA3_;
		T5_ = (NIM_BOOL)0;
		T5_ = hasCommand__reorder_693((*n).pnode);
		(*n).hCmd = T5_;
	}
	LA3_: ;
	result = (((*n).hCmd) != 0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasImportStmt__reorder_683)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 116):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 120):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 117):
	{
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 126):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 93):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 86):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 88):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 113):
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a;
			a = NIM_NIL;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_3148(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA6;
						i = i_2;
						a = (*n)._kind_6.sons->data[i];
						{
							NIM_BOOL T9_;
							T9_ = (NIM_BOOL)0;
							T9_ = hasImportStmt__reorder_683(a);
							if (!T9_) goto LA10_;
							result = NIM_TRUE;
							goto BeforeRet_;
						}
						LA10_: ;
						i_2 += ((NI) 1);
					} LA6: ;
				}
			}
		}
	}
	break;
	default:
	{
		result = NIM_FALSE;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasImportStmt__reorder_687)(tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA* n) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		NIM_BOOL T5_;
		if (!((*n).hIS < ((NI) 0))) goto LA3_;
		T5_ = (NIM_BOOL)0;
		T5_ = hasImportStmt__reorder_683((*n).pnode);
		(*n).hIS = T5_;
	}
	LA3_: ;
	result = (((*n).hIS) != 0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasAccQuoted__reorder_703)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 53))) goto LA3_;
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a;
		a = NIM_NIL;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_3148(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA8;
					i = i_2;
					a = (*n)._kind_6.sons->data[i];
					{
						NIM_BOOL T11_;
						T11_ = (NIM_BOOL)0;
						T11_ = hasAccQuoted__reorder_703(a);
						if (!T11_) goto LA12_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
					LA12_: ;
					i_2 += ((NI) 1);
				} LA8: ;
			}
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasAccQuotedDef__reorder_716)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 51) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 52):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 79) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 84):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 159):
	{
		result = hasAccQuoted__reorder_703((*n)._kind_6.sons->data[((NI) 0)]);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 126):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 93):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 86):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 88):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 113):
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a;
			a = NIM_NIL;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_3148(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA6;
						i = i_2;
						a = (*n)._kind_6.sons->data[i];
						{
							NIM_BOOL T9_;
							T9_ = (NIM_BOOL)0;
							T9_ = hasAccQuotedDef__reorder_716(a);
							if (!T9_) goto LA10_;
							result = NIM_TRUE;
							goto BeforeRet_;
						}
						LA10_: ;
						i_2 += ((NI) 1);
					} LA6: ;
				}
			}
		}
	}
	break;
	default:
	{
		result = NIM_FALSE;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasAccQuotedDef__reorder_721)(tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA* n) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		NIM_BOOL T5_;
		if (!((*n).hAQ < ((NI) 0))) goto LA3_;
		T5_ = (NIM_BOOL)0;
		T5_ = hasAccQuotedDef__reorder_716((*n).pnode);
		(*n).hAQ = T5_;
	}
	LA3_: ;
	result = (((*n).hAQ) != 0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, intersects__reorder_746)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s1, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s2) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		NI a;
		a = (NI)0;
		{
			if (!((*s1).elems <= ((NI) 34))) goto LA4_;
			{
				NI i;
				NI i_2;
				i = (NI)0;
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < (*s1).elems)) goto LA8;
						i = i_2;
						a = (*s1).a[(i)- 0];
						{
							NIM_BOOL T11_;
							T11_ = (NIM_BOOL)0;
							T11_ = contains__astalgo_3489(s2, a);
							if (!T11_) goto LA12_;
							result = NIM_TRUE;
							goto BeforeRet_;
						}
						LA12_: ;
						i_2 += ((NI) 1);
					} LA8: ;
				}
			}
		}
		goto LA2_;
		LA4_: ;
		{
			tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* r;
			r = (*s1).head;
			{
				while (1) {
					NI i_3;
					if (!!((r == ((tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg*) NIM_NIL)))) goto LA16;
					i_3 = ((NI) 0);
					{
						while (1) {
							NU w;
							NI j;
							if (!(i_3 <= ((NI) 15))) goto LA18;
							w = (*r).bits[(i_3)- 0];
							j = ((NI) 0);
							{
								while (1) {
									if (!!((w == ((NU) 0)))) goto LA20;
									{
										NI T25_;
										if (!!(((NU)(w & ((NU) 1)) == ((NU) 0)))) goto LA23_;
										T25_ = (NI)0;
										T25_ = pluspercent___system_696((NI)((NU32)(i_3) << (NU32)(((NI) 5))), j);
										a = (NI)((NI)((NU32)((*r).key) << (NU32)(((NI) 9))) | T25_);
										{
											NIM_BOOL T28_;
											T28_ = (NIM_BOOL)0;
											T28_ = contains__astalgo_3489(s2, a);
											if (!T28_) goto LA29_;
											result = NIM_TRUE;
											goto BeforeRet_;
										}
										LA29_: ;
									}
									LA23_: ;
									j += ((NI) 1);
									w = (NU)((NU32)(w) >> (NU32)(((NI) 1)));
								} LA20: ;
							}
							i_3 += ((NI) 1);
						} LA18: ;
					}
					r = (*r).next;
				} LA16: ;
			}
		}
		LA2_: ;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__vAEg9bb6P9cAvzrQae7aeKyA*, buildGraph__reorder_760)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySequence__fZ9aerq6GRgd1Id9b1cf7NuA* deps) {
	tySequence__vAEg9bb6P9cAvzrQae7aeKyA* result;
	NI T1_;
	result = NIM_NIL;
	T1_ = (deps ? deps->Sup.len : 0);
	result = (tySequence__vAEg9bb6P9cAvzrQae7aeKyA*)nimNewSeqOfCap((&NTIseqLdepnT__vAEg9bb6P9cAvzrQae7aeKyA_), ((NI) (T1_)));
	{
		NI i;
		NI colontmp_;
		NI T3_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T3_ = (deps ? deps->Sup.len : 0);
		colontmp_ = T3_;
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA* T6_;
				NI T7_;
				if (!(i_2 < colontmp_)) goto LA5;
				i = i_2;
				T6_ = NIM_NIL;
				T6_ = newDepN__reorder_26(i, (*n)._kind_6.sons->data[i]);
				result = (tySequence__vAEg9bb6P9cAvzrQae7aeKyA*) incrSeqV3((TGenericSeq*)(result), (&NTIseqLdepnT__vAEg9bb6P9cAvzrQae7aeKyA_));
				T7_ = result->Sup.len++;
				asgnRef((void**) (&result->data[T7_]), T6_);
				i_2 += ((NI) 1);
			} LA5: ;
		}
	}
	{
		NI i_3;
		NI colontmp__2;
		NI T9_;
		NI i_4;
		i_3 = (NI)0;
		colontmp__2 = (NI)0;
		T9_ = (deps ? deps->Sup.len : 0);
		colontmp__2 = T9_;
		i_4 = ((NI) 0);
		{
			while (1) {
				tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA* ni;
				tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw uses;
				NIM_BOOL niHasBody;
				NIM_BOOL niHasCmd;
				if (!(i_4 < colontmp__2)) goto LA11;
				i_3 = i_4;
				ni = result->data[i_3];
				nimZeroMem((void*)(&uses), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
				nimCopyMem((void*)(&uses), (NIM_CONST void*)(&deps->data[i_3].Field1), sizeof(uses));
				niHasBody = hasBody__reorder_740(ni);
				niHasCmd = hasCommand__reorder_697(ni);
				{
					NI j;
					NI colontmp__3;
					NI T13_;
					NI i_5;
					j = (NI)0;
					colontmp__3 = (NI)0;
					T13_ = (deps ? deps->Sup.len : 0);
					colontmp__3 = T13_;
					i_5 = ((NI) 0);
					{
						while (1) {
							if (!(i_5 < colontmp__3)) goto LA15;
							j = i_5;
							{
								tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA* nj;
								tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw declares;
								{
									if (!(i_3 == j)) goto LA19_;
									goto LA16;
								}
								LA19_: ;
								nj = result->data[j];
								nimZeroMem((void*)(&declares), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
								nimCopyMem((void*)(&declares), (NIM_CONST void*)(&deps->data[j].Field0), sizeof(declares));
								{
									NIM_BOOL T23_;
									NIM_BOOL T24_;
									NI T29_;
									T23_ = (NIM_BOOL)0;
									T24_ = (NIM_BOOL)0;
									T24_ = (j < i_3);
									if (!(T24_)) goto LA25_;
									T24_ = hasCommand__reorder_697(nj);
									LA25_: ;
									T23_ = T24_;
									if (!(T23_)) goto LA26_;
									T23_ = niHasCmd;
									LA26_: ;
									if (!T23_) goto LA27_;
									asgnRef((void**) (&(*ni).kids), (tySequence__vAEg9bb6P9cAvzrQae7aeKyA*) incrSeqV3((TGenericSeq*)((*ni).kids), (&NTIseqLdepnT__vAEg9bb6P9cAvzrQae7aeKyA_)));
									T29_ = (*ni).kids->Sup.len++;
									asgnRef((void**) (&(*ni).kids->data[T29_]), nj);
								}
								goto LA21_;
								LA27_: ;
								{
									NIM_BOOL T31_;
									NI T35_;
									T31_ = (NIM_BOOL)0;
									T31_ = (j < i_3);
									if (!(T31_)) goto LA32_;
									T31_ = hasImportStmt__reorder_687(nj);
									LA32_: ;
									if (!T31_) goto LA33_;
									asgnRef((void**) (&(*ni).kids), (tySequence__vAEg9bb6P9cAvzrQae7aeKyA*) incrSeqV3((TGenericSeq*)((*ni).kids), (&NTIseqLdepnT__vAEg9bb6P9cAvzrQae7aeKyA_)));
									T35_ = (*ni).kids->Sup.len++;
									asgnRef((void**) (&(*ni).kids->data[T35_]), nj);
								}
								goto LA21_;
								LA33_: ;
								{
									NIM_BOOL T37_;
									NIM_BOOL T38_;
									NI T43_;
									T37_ = (NIM_BOOL)0;
									T38_ = (NIM_BOOL)0;
									T38_ = (j < i_3);
									if (!(T38_)) goto LA39_;
									T38_ = niHasBody;
									LA39_: ;
									T37_ = T38_;
									if (!(T37_)) goto LA40_;
									T37_ = hasAccQuotedDef__reorder_721(nj);
									LA40_: ;
									if (!T37_) goto LA41_;
									asgnRef((void**) (&(*ni).kids), (tySequence__vAEg9bb6P9cAvzrQae7aeKyA*) incrSeqV3((TGenericSeq*)((*ni).kids), (&NTIseqLdepnT__vAEg9bb6P9cAvzrQae7aeKyA_)));
									T43_ = (*ni).kids->Sup.len++;
									asgnRef((void**) (&(*ni).kids->data[T43_]), nj);
								}
								goto LA21_;
								LA41_: ;
								{
									NIM_BOOL T45_;
									NIM_BOOL T46_;
									NIM_BOOL T47_;
									NIM_BOOL T50_;
									NI T54_;
									T45_ = (NIM_BOOL)0;
									T46_ = (NIM_BOOL)0;
									T47_ = (NIM_BOOL)0;
									T47_ = (j < i_3);
									if (!(T47_)) goto LA48_;
									T47_ = niHasBody;
									LA48_: ;
									T46_ = T47_;
									if (!(T46_)) goto LA49_;
									T50_ = (NIM_BOOL)0;
									T50_ = hasBody__reorder_740(nj);
									T46_ = !(T50_);
									LA49_: ;
									T45_ = T46_;
									if (!(T45_)) goto LA51_;
									T45_ = intersects__reorder_746((&deps->data[i_3].Field0), (&declares));
									LA51_: ;
									if (!T45_) goto LA52_;
									asgnRef((void**) (&(*ni).kids), (tySequence__vAEg9bb6P9cAvzrQae7aeKyA*) incrSeqV3((TGenericSeq*)((*ni).kids), (&NTIseqLdepnT__vAEg9bb6P9cAvzrQae7aeKyA_)));
									T54_ = (*ni).kids->Sup.len++;
									asgnRef((void**) (&(*ni).kids->data[T54_]), nj);
								}
								goto LA21_;
								LA52_: ;
								{
									{
										NI d;
										d = (NI)0;
										{
											if (!(declares.elems <= ((NI) 34))) goto LA59_;
											{
												NI i_6;
												NI i_7;
												i_6 = (NI)0;
												i_7 = ((NI) 0);
												{
													while (1) {
														if (!(i_7 < declares.elems)) goto LA63;
														i_6 = i_7;
														d = declares.a[(i_6)- 0];
														{
															NIM_BOOL T66_;
															NI T69_;
															T66_ = (NIM_BOOL)0;
															T66_ = contains__astalgo_3489((&uses), d);
															if (!T66_) goto LA67_;
															asgnRef((void**) (&(*ni).kids), (tySequence__vAEg9bb6P9cAvzrQae7aeKyA*) incrSeqV3((TGenericSeq*)((*ni).kids), (&NTIseqLdepnT__vAEg9bb6P9cAvzrQae7aeKyA_)));
															T69_ = (*ni).kids->Sup.len++;
															asgnRef((void**) (&(*ni).kids->data[T69_]), nj);
														}
														LA67_: ;
														i_7 += ((NI) 1);
													} LA63: ;
												}
											}
										}
										goto LA57_;
										LA59_: ;
										{
											tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* r;
											r = declares.head;
											{
												while (1) {
													NI i_8;
													if (!!((r == ((tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg*) NIM_NIL)))) goto LA72;
													i_8 = ((NI) 0);
													{
														while (1) {
															NU w;
															NI j_2;
															if (!(i_8 <= ((NI) 15))) goto LA74;
															w = (*r).bits[(i_8)- 0];
															j_2 = ((NI) 0);
															{
																while (1) {
																	if (!!((w == ((NU) 0)))) goto LA76;
																	{
																		NI T81_;
																		if (!!(((NU)(w & ((NU) 1)) == ((NU) 0)))) goto LA79_;
																		T81_ = (NI)0;
																		T81_ = pluspercent___system_696((NI)((NU32)(i_8) << (NU32)(((NI) 5))), j_2);
																		d = (NI)((NI)((NU32)((*r).key) << (NU32)(((NI) 9))) | T81_);
																		{
																			NIM_BOOL T84_;
																			NI T87_;
																			T84_ = (NIM_BOOL)0;
																			T84_ = contains__astalgo_3489((&uses), d);
																			if (!T84_) goto LA85_;
																			asgnRef((void**) (&(*ni).kids), (tySequence__vAEg9bb6P9cAvzrQae7aeKyA*) incrSeqV3((TGenericSeq*)((*ni).kids), (&NTIseqLdepnT__vAEg9bb6P9cAvzrQae7aeKyA_)));
																			T87_ = (*ni).kids->Sup.len++;
																			asgnRef((void**) (&(*ni).kids->data[T87_]), nj);
																		}
																		LA85_: ;
																	}
																	LA79_: ;
																	j_2 += ((NI) 1);
																	w = (NU)((NU32)(w) >> (NU32)(((NI) 1)));
																} LA76: ;
															}
															i_8 += ((NI) 1);
														} LA74: ;
													}
													r = (*r).next;
												} LA72: ;
											}
										}
										LA57_: ;
									}
								}
								LA21_: ;
							} LA16: ;
							i_5 += ((NI) 1);
						} LA15: ;
					}
				}
				i_4 += ((NI) 1);
			} LA11: ;
		}
	}
	return result;
}
static N_INLINE(tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA*, pop__reorder_877)(tySequence__vAEg9bb6P9cAvzrQae7aeKyA** s) {
	tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA* result;
	NI L;
	NI T1_;
	result = NIM_NIL;
	T1_ = ((*s) ? (*s)->Sup.len : 0);
	L = (NI)(T1_ - ((NI) 1));
	result = (*s)->data[L];
	unsureAsgnRef((void**) (&(*s)), (tySequence__vAEg9bb6P9cAvzrQae7aeKyA*) setLengthSeqV2(((*s))?&((*s))->Sup:NIM_NIL, (&NTIseqLdepnT__vAEg9bb6P9cAvzrQae7aeKyA_), ((NI) (L))));
	return result;
}
static N_NIMCALL(void, Marker_tySequence__AT39bF59bUK7pfvl9asfwzQ6A)(void* p, NI op) {
	tySequence__AT39bF59bUK7pfvl9asfwzQ6A* a;
	NI T1_;
	a = (tySequence__AT39bF59bUK7pfvl9asfwzQ6A*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_], op);
	}
}
N_LIB_PRIVATE N_NIMCALL(void, strongConnect__reorder_837)(tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA** v, NI* idx, tySequence__vAEg9bb6P9cAvzrQae7aeKyA** s, tySequence__AT39bF59bUK7pfvl9asfwzQ6A** res) {
	NI T1_;
	(*(*v)).idx = (*idx);
	(*(*v)).lowLink = (*idx);
	(*idx) += ((NI) 1);
	unsureAsgnRef((void**) (&(*s)), (tySequence__vAEg9bb6P9cAvzrQae7aeKyA*) incrSeqV3((TGenericSeq*)((*s)), (&NTIseqLdepnT__vAEg9bb6P9cAvzrQae7aeKyA_)));
	T1_ = (*s)->Sup.len++;
	asgnRef((void**) (&(*s)->data[T1_]), (*v));
	(*(*v)).onStack = NIM_TRUE;
	{
		tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA** w;
		NI i;
		NI L;
		NI T3_;
		w = (tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA**)0;
		i = ((NI) 0);
		T3_ = ((*(*v)).kids ? (*(*v)).kids->Sup.len : 0);
		L = T3_;
		{
			while (1) {
				if (!(i < L)) goto LA5;
				w = &(*(*v)).kids->data[i];
				{
					if (!((*(*w)).idx < ((NI) 0))) goto LA8_;
					strongConnect__reorder_837(w, idx, s, res);
					(*(*v)).lowLink = (((*(*v)).lowLink <= (*(*w)).lowLink) ? (*(*v)).lowLink : (*(*w)).lowLink);
				}
				goto LA6_;
				LA8_: ;
				{
					if (!(*(*w)).onStack) goto LA11_;
					(*(*v)).lowLink = (((*(*v)).lowLink <= (*(*w)).idx) ? (*(*v)).lowLink : (*(*w)).idx);
				}
				goto LA6_;
				LA11_: ;
				LA6_: ;
				i += ((NI) 1);
			} LA5: ;
		}
	}
	{
		tySequence__vAEg9bb6P9cAvzrQae7aeKyA* comp;
		NI T24_;
		if (!((*(*v)).lowLink == (*(*v)).idx)) goto LA15_;
		comp = newSeq__reorder_478(((NI) 0));
		{
			while (1) {
				tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA* w_2;
				NI T19_;
				w_2 = pop__reorder_877(s);
				(*w_2).onStack = NIM_FALSE;
				comp = (tySequence__vAEg9bb6P9cAvzrQae7aeKyA*) incrSeqV3((TGenericSeq*)(comp), (&NTIseqLdepnT__vAEg9bb6P9cAvzrQae7aeKyA_));
				T19_ = comp->Sup.len++;
				asgnRef((void**) (&comp->data[T19_]), w_2);
				{
					if (!((*w_2).id == (*(*v)).id)) goto LA22_;
					goto LA17;
				}
				LA22_: ;
			}
		} LA17: ;
		unsureAsgnRef((void**) (&(*res)), (tySequence__AT39bF59bUK7pfvl9asfwzQ6A*) incrSeqV3((TGenericSeq*)((*res)), (&NTIseqLseqLdepnTT__AT39bF59bUK7pfvl9asfwzQ6A_)));
		T24_ = (*res)->Sup.len++;
		genericSeqAssign((&(*res)->data[T24_]), comp, (&NTIseqLdepnT__vAEg9bb6P9cAvzrQae7aeKyA_));
	}
	LA15_: ;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__AT39bF59bUK7pfvl9asfwzQ6A*, getStrongComponents__reorder_916)(tySequence__vAEg9bb6P9cAvzrQae7aeKyA** g) {
	tySequence__AT39bF59bUK7pfvl9asfwzQ6A* result;
	tySequence__vAEg9bb6P9cAvzrQae7aeKyA* s;
	NI idx;
	result = NIM_NIL;
	s = NIM_NIL;
	idx = ((NI) 0);
	{
		tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA** v;
		NI i;
		NI L;
		NI T2_;
		v = (tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA**)0;
		i = ((NI) 0);
		T2_ = ((*g) ? (*g)->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				if (!(i < L)) goto LA4;
				v = &(*g)->data[i];
				{
					if (!((*(*v)).idx < ((NI) 0))) goto LA7_;
					strongConnect__reorder_837(v, (&idx), (&s), (&result));
				}
				LA7_: ;
				i += ((NI) 1);
			} LA4: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, colonanonymous___reorder_448)(tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA* xX60gensym51_, tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA* yX60gensym51_) {
	NI result;
	tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA* it;
	NI aX60gensym51_;
	NI bX60gensym51_;
	result = (NI)0;
	it = xX60gensym51_;
	aX60gensym51_ = (*it).id;
	it = yX60gensym51_;
	bX60gensym51_ = (*it).id;
	result = cmp__system_7445(aX60gensym51_, bX60gensym51_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, haveSameKind__reorder_367)(tySequence__vAEg9bb6P9cAvzrQae7aeKyA* dns) {
	NIM_BOOL result;
	tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
{	result = (NIM_BOOL)0;
	result = NIM_TRUE;
	kind = (*(*dns->data[((NI) 0)]).pnode).kind;
	{
		tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA** dn;
		NI i;
		NI L;
		NI T2_;
		dn = (tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA**)0;
		i = ((NI) 0);
		T2_ = (dns ? dns->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				if (!(i < L)) goto LA4;
				dn = &dns->data[i];
				{
					if (!!(((*(*(*dn)).pnode).kind == kind))) goto LA7_;
					result = NIM_FALSE;
					goto BeforeRet_;
				}
				LA7_: ;
				i += ((NI) 1);
			} LA4: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, mergeSections__reorder_404)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tySequence__AT39bF59bUK7pfvl9asfwzQ6A* comps, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* res) {
	{
		tySequence__vAEg9bb6P9cAvzrQae7aeKyA** c;
		NI i;
		NI L;
		NI T2_;
		c = (tySequence__vAEg9bb6P9cAvzrQae7aeKyA**)0;
		i = ((NI) 0);
		T2_ = (comps ? comps->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				if (!(i < L)) goto LA4;
				c = (&comps->data[i]);
				{
					NI T7_;
					T7_ = ((*c) ? (*c)->Sup.len : 0);
					if (!(T7_ == ((NI) 1))) goto LA8_;
					add__ast_4798(res, (*(*c)->data[((NI) 0)]).pnode);
				}
				goto LA5_;
				LA8_: ;
				{
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* fstn;
					tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
					tySequence__vAEg9bb6P9cAvzrQae7aeKyA* cs;
					tySequence__vAEg9bb6P9cAvzrQae7aeKyA* resultX60gensym51_;
					tyProc__YRIBfnKx4fhbilJmrYB0MA T11_;
					fstn = (*(*c)->data[((NI) 0)]).pnode;
					kind = (*fstn).kind;
					nimZeroMem((void*)(&T11_), sizeof(tyProc__YRIBfnKx4fhbilJmrYB0MA));
					T11_.ClP_0 = ((TM__k9axqyY7R0TmDVutx9brQukQ_9) (colonanonymous___reorder_448)); T11_.ClE_0 = NIM_NIL;
					resultX60gensym51_ = sorted__reorder_466(((*c)) ? ((*c)->data) : NIM_NIL, ((*c) ? (*c)->Sup.len : 0), T11_, ((tyEnum_SortOrder__TcYjciSJ3jKUT4ygglumjg) 1));
					cs = resultX60gensym51_;
					{
						NIM_BOOL T14_;
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* sn;
						T14_ = (NIM_BOOL)0;
						T14_ = (kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 98) || kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 101));
						if (!(T14_)) goto LA15_;
						T14_ = haveSameKind__reorder_367(cs);
						LA15_: ;
						if (!T14_) goto LA16_;
						sn = newNode__ast_3289(kind);
						{
							tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA** dn;
							NI i_2;
							NI L_2;
							NI T19_;
							dn = (tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA**)0;
							i_2 = ((NI) 0);
							T19_ = (cs ? cs->Sup.len : 0);
							L_2 = T19_;
							{
								while (1) {
									if (!(i_2 < L_2)) goto LA21;
									dn = &cs->data[i_2];
									add__ast_4798(sn, (*(*(*dn)).pnode)._kind_6.sons->data[((NI) 0)]);
									i_2 += ((NI) 1);
								} LA21: ;
							}
						}
						add__ast_4798(res, sn);
					}
					goto LA12_;
					LA16_: ;
					{
						NimStringDesc* wmsg;
						NI i_3;
						wmsg = copyString(((NimStringDesc*) &TM__k9axqyY7R0TmDVutx9brQukQ_10));
						liMessage__msgs_1128(conf, (*(*cs->data[((NI) 0)]).pnode).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 71), wmsg, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__k9axqyY7R0TmDVutx9brQukQ_11, NIM_FALSE);
						i_3 = ((NI) 0);
						{
							while (1) {
								NI T25_;
								T25_ = (cs ? cs->Sup.len : 0);
								if (!(i_3 < T25_)) goto LA24;
								{
									tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw ckind;
									tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* sn_2;
									if (!((*(*cs->data[i_3]).pnode).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 98) || (*(*cs->data[i_3]).pnode).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 101))) goto LA28_;
									ckind = (*(*cs->data[i_3]).pnode).kind;
									sn_2 = newNode__ast_3289(ckind);
									add__ast_4798(sn_2, (*(*cs->data[i_3]).pnode)._kind_6.sons->data[((NI) 0)]);
									i_3 += ((NI) 1);
									{
										while (1) {
											NIM_BOOL T32_;
											NI T33_;
											T32_ = (NIM_BOOL)0;
											T33_ = (cs ? cs->Sup.len : 0);
											T32_ = (i_3 < T33_);
											if (!(T32_)) goto LA34_;
											T32_ = ((*(*cs->data[i_3]).pnode).kind == ckind);
											LA34_: ;
											if (!T32_) goto LA31;
											add__ast_4798(sn_2, (*(*cs->data[i_3]).pnode)._kind_6.sons->data[((NI) 0)]);
											i_3 += ((NI) 1);
										} LA31: ;
									}
									add__ast_4798(res, sn_2);
								}
								goto LA26_;
								LA28_: ;
								{
									add__ast_4798(res, (*cs->data[i_3]).pnode);
									i_3 += ((NI) 1);
								}
								LA26_: ;
							} LA24: ;
						}
					}
					LA12_: ;
				}
				LA5_: ;
				i += ((NI) 1);
			} LA4: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, reorder__reorder_939)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw includedFiles;
	NimStringDesc* mpath;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n_2;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T6_;
	tySequence__fZ9aerq6GRgd1Id9b1cf7NuA* deps;
	NI T7_;
	tySequence__vAEg9bb6P9cAvzrQae7aeKyA* g;
	tySequence__AT39bF59bUK7pfvl9asfwzQ6A* comps;
{	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = hasForbiddenPragma__reorder_925(n);
		if (!T3_) goto LA4_;
		result = n;
		goto BeforeRet_;
	}
	LA4_: ;
	nimZeroMem((void*)(&includedFiles), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
	initIntSet__pureZcollectionsZintsets_238((&includedFiles));
	mpath = toFullPath__msgs_548((*graph).config, ((NI32) ((*module).position)));
	T6_ = NIM_NIL;
	T6_ = expandIncludes__reorder_245(graph, module, n, mpath, (&includedFiles));
	n_2 = splitSections__reorder_335(T6_);
	result = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115), (*n_2).info);
	T7_ = (NI)0;
	T7_ = len__ast_3155(n_2);
	deps = newSeq__reorder_951(((NI) (T7_)));
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(n_2);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA10;
				i = i_2;
				initIntSet__pureZcollectionsZintsets_238((&deps->data[i].Field0));
				initIntSet__pureZcollectionsZintsets_238((&deps->data[i].Field1));
				computeDeps__reorder_108((*graph).cache, (*n_2)._kind_6.sons->data[i], (&deps->data[i].Field0), (&deps->data[i].Field1), NIM_TRUE);
				i_2 += ((NI) 1);
			} LA10: ;
		}
	}
	g = buildGraph__reorder_760(n_2, deps);
	comps = getStrongComponents__reorder_916((&g));
	mergeSections__reorder_404((*graph).config, comps, result);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, atmreorderdotnim_DatInit000)(void) {
static TNimNode* TM__k9axqyY7R0TmDVutx9brQukQ_6_2[2];
static TNimNode* TM__k9axqyY7R0TmDVutx9brQukQ_8_10[10];
static TNimNode TM__k9axqyY7R0TmDVutx9brQukQ_0[14];
NTILintset_intsetT__D9cr9aW4733sg56WAiSRpttQ_.size = sizeof(tyTuple__D9cr9aW4733sg56WAiSRpttQ);
NTILintset_intsetT__D9cr9aW4733sg56WAiSRpttQ_.align = NIM_ALIGNOF(tyTuple__D9cr9aW4733sg56WAiSRpttQ);
NTILintset_intsetT__D9cr9aW4733sg56WAiSRpttQ_.kind = 18;
NTILintset_intsetT__D9cr9aW4733sg56WAiSRpttQ_.base = 0;
NTILintset_intsetT__D9cr9aW4733sg56WAiSRpttQ_.flags = 2;
TM__k9axqyY7R0TmDVutx9brQukQ_6_2[0] = &TM__k9axqyY7R0TmDVutx9brQukQ_0[1];
TM__k9axqyY7R0TmDVutx9brQukQ_0[1].kind = 1;
TM__k9axqyY7R0TmDVutx9brQukQ_0[1].offset = offsetof(tyTuple__D9cr9aW4733sg56WAiSRpttQ, Field0);
TM__k9axqyY7R0TmDVutx9brQukQ_0[1].typ = (&NTIpackedset__THXDbzJSs2hcC9a33en2pdw_);
TM__k9axqyY7R0TmDVutx9brQukQ_0[1].name = "Field0";
TM__k9axqyY7R0TmDVutx9brQukQ_6_2[1] = &TM__k9axqyY7R0TmDVutx9brQukQ_0[2];
TM__k9axqyY7R0TmDVutx9brQukQ_0[2].kind = 1;
TM__k9axqyY7R0TmDVutx9brQukQ_0[2].offset = offsetof(tyTuple__D9cr9aW4733sg56WAiSRpttQ, Field1);
TM__k9axqyY7R0TmDVutx9brQukQ_0[2].typ = (&NTIpackedset__THXDbzJSs2hcC9a33en2pdw_);
TM__k9axqyY7R0TmDVutx9brQukQ_0[2].name = "Field1";
TM__k9axqyY7R0TmDVutx9brQukQ_0[0].len = 2; TM__k9axqyY7R0TmDVutx9brQukQ_0[0].kind = 2; TM__k9axqyY7R0TmDVutx9brQukQ_0[0].sons = &TM__k9axqyY7R0TmDVutx9brQukQ_6_2[0];
NTILintset_intsetT__D9cr9aW4733sg56WAiSRpttQ_.node = &TM__k9axqyY7R0TmDVutx9brQukQ_0[0];
NTIseqLLintset_intsetTT__fZ9aerq6GRgd1Id9b1cf7NuA_.size = sizeof(tySequence__fZ9aerq6GRgd1Id9b1cf7NuA*);
NTIseqLLintset_intsetTT__fZ9aerq6GRgd1Id9b1cf7NuA_.align = NIM_ALIGNOF(tySequence__fZ9aerq6GRgd1Id9b1cf7NuA*);
NTIseqLLintset_intsetTT__fZ9aerq6GRgd1Id9b1cf7NuA_.kind = 24;
NTIseqLLintset_intsetTT__fZ9aerq6GRgd1Id9b1cf7NuA_.base = (&NTILintset_intsetT__D9cr9aW4733sg56WAiSRpttQ_);
NTIseqLLintset_intsetTT__fZ9aerq6GRgd1Id9b1cf7NuA_.flags = 2;
NTIseqLLintset_intsetTT__fZ9aerq6GRgd1Id9b1cf7NuA_.marker = Marker_tySequence__fZ9aerq6GRgd1Id9b1cf7NuA;
NTIdepn58objecttype__T7a6etQXL0CBg8BjsbsXpA_.size = sizeof(tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA);
NTIdepn58objecttype__T7a6etQXL0CBg8BjsbsXpA_.align = NIM_ALIGNOF(tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA);
NTIdepn58objecttype__T7a6etQXL0CBg8BjsbsXpA_.kind = 18;
NTIdepn58objecttype__T7a6etQXL0CBg8BjsbsXpA_.base = 0;
TM__k9axqyY7R0TmDVutx9brQukQ_8_10[0] = &TM__k9axqyY7R0TmDVutx9brQukQ_0[4];
TM__k9axqyY7R0TmDVutx9brQukQ_0[4].kind = 1;
TM__k9axqyY7R0TmDVutx9brQukQ_0[4].offset = offsetof(tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA, pnode);
TM__k9axqyY7R0TmDVutx9brQukQ_0[4].typ = (&NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_);
TM__k9axqyY7R0TmDVutx9brQukQ_0[4].name = "pnode";
TM__k9axqyY7R0TmDVutx9brQukQ_8_10[1] = &TM__k9axqyY7R0TmDVutx9brQukQ_0[5];
TM__k9axqyY7R0TmDVutx9brQukQ_0[5].kind = 1;
TM__k9axqyY7R0TmDVutx9brQukQ_0[5].offset = offsetof(tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA, id);
TM__k9axqyY7R0TmDVutx9brQukQ_0[5].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__k9axqyY7R0TmDVutx9brQukQ_0[5].name = "id";
TM__k9axqyY7R0TmDVutx9brQukQ_8_10[2] = &TM__k9axqyY7R0TmDVutx9brQukQ_0[6];
TM__k9axqyY7R0TmDVutx9brQukQ_0[6].kind = 1;
TM__k9axqyY7R0TmDVutx9brQukQ_0[6].offset = offsetof(tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA, idx);
TM__k9axqyY7R0TmDVutx9brQukQ_0[6].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__k9axqyY7R0TmDVutx9brQukQ_0[6].name = "idx";
TM__k9axqyY7R0TmDVutx9brQukQ_8_10[3] = &TM__k9axqyY7R0TmDVutx9brQukQ_0[7];
TM__k9axqyY7R0TmDVutx9brQukQ_0[7].kind = 1;
TM__k9axqyY7R0TmDVutx9brQukQ_0[7].offset = offsetof(tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA, lowLink);
TM__k9axqyY7R0TmDVutx9brQukQ_0[7].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__k9axqyY7R0TmDVutx9brQukQ_0[7].name = "lowLink";
TM__k9axqyY7R0TmDVutx9brQukQ_8_10[4] = &TM__k9axqyY7R0TmDVutx9brQukQ_0[8];
TM__k9axqyY7R0TmDVutx9brQukQ_0[8].kind = 1;
TM__k9axqyY7R0TmDVutx9brQukQ_0[8].offset = offsetof(tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA, onStack);
TM__k9axqyY7R0TmDVutx9brQukQ_0[8].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__k9axqyY7R0TmDVutx9brQukQ_0[8].name = "onStack";
TM__k9axqyY7R0TmDVutx9brQukQ_8_10[5] = &TM__k9axqyY7R0TmDVutx9brQukQ_0[9];
TM__k9axqyY7R0TmDVutx9brQukQ_0[9].kind = 1;
TM__k9axqyY7R0TmDVutx9brQukQ_0[9].offset = offsetof(tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA, kids);
TM__k9axqyY7R0TmDVutx9brQukQ_0[9].typ = (&NTIseqLdepnT__vAEg9bb6P9cAvzrQae7aeKyA_);
TM__k9axqyY7R0TmDVutx9brQukQ_0[9].name = "kids";
TM__k9axqyY7R0TmDVutx9brQukQ_8_10[6] = &TM__k9axqyY7R0TmDVutx9brQukQ_0[10];
TM__k9axqyY7R0TmDVutx9brQukQ_0[10].kind = 1;
TM__k9axqyY7R0TmDVutx9brQukQ_0[10].offset = offsetof(tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA, hAQ);
TM__k9axqyY7R0TmDVutx9brQukQ_0[10].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__k9axqyY7R0TmDVutx9brQukQ_0[10].name = "hAQ";
TM__k9axqyY7R0TmDVutx9brQukQ_8_10[7] = &TM__k9axqyY7R0TmDVutx9brQukQ_0[11];
TM__k9axqyY7R0TmDVutx9brQukQ_0[11].kind = 1;
TM__k9axqyY7R0TmDVutx9brQukQ_0[11].offset = offsetof(tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA, hIS);
TM__k9axqyY7R0TmDVutx9brQukQ_0[11].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__k9axqyY7R0TmDVutx9brQukQ_0[11].name = "hIS";
TM__k9axqyY7R0TmDVutx9brQukQ_8_10[8] = &TM__k9axqyY7R0TmDVutx9brQukQ_0[12];
TM__k9axqyY7R0TmDVutx9brQukQ_0[12].kind = 1;
TM__k9axqyY7R0TmDVutx9brQukQ_0[12].offset = offsetof(tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA, hB);
TM__k9axqyY7R0TmDVutx9brQukQ_0[12].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__k9axqyY7R0TmDVutx9brQukQ_0[12].name = "hB";
TM__k9axqyY7R0TmDVutx9brQukQ_8_10[9] = &TM__k9axqyY7R0TmDVutx9brQukQ_0[13];
TM__k9axqyY7R0TmDVutx9brQukQ_0[13].kind = 1;
TM__k9axqyY7R0TmDVutx9brQukQ_0[13].offset = offsetof(tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA, hCmd);
TM__k9axqyY7R0TmDVutx9brQukQ_0[13].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__k9axqyY7R0TmDVutx9brQukQ_0[13].name = "hCmd";
TM__k9axqyY7R0TmDVutx9brQukQ_0[3].len = 10; TM__k9axqyY7R0TmDVutx9brQukQ_0[3].kind = 2; TM__k9axqyY7R0TmDVutx9brQukQ_0[3].sons = &TM__k9axqyY7R0TmDVutx9brQukQ_8_10[0];
NTIdepn58objecttype__T7a6etQXL0CBg8BjsbsXpA_.node = &TM__k9axqyY7R0TmDVutx9brQukQ_0[3];
NTIdepn__Si6SFYrfWmFpQSJlvZ5FVA_.size = sizeof(tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA*);
NTIdepn__Si6SFYrfWmFpQSJlvZ5FVA_.align = NIM_ALIGNOF(tyObject_DepNcolonObjectType___T7a6etQXL0CBg8BjsbsXpA*);
NTIdepn__Si6SFYrfWmFpQSJlvZ5FVA_.kind = 22;
NTIdepn__Si6SFYrfWmFpQSJlvZ5FVA_.base = (&NTIdepn58objecttype__T7a6etQXL0CBg8BjsbsXpA_);
NTIdepn__Si6SFYrfWmFpQSJlvZ5FVA_.marker = Marker_tyRef__Si6SFYrfWmFpQSJlvZ5FVA;
NTIseqLdepnT__vAEg9bb6P9cAvzrQae7aeKyA_.size = sizeof(tySequence__vAEg9bb6P9cAvzrQae7aeKyA*);
NTIseqLdepnT__vAEg9bb6P9cAvzrQae7aeKyA_.align = NIM_ALIGNOF(tySequence__vAEg9bb6P9cAvzrQae7aeKyA*);
NTIseqLdepnT__vAEg9bb6P9cAvzrQae7aeKyA_.kind = 24;
NTIseqLdepnT__vAEg9bb6P9cAvzrQae7aeKyA_.base = (&NTIdepn__Si6SFYrfWmFpQSJlvZ5FVA_);
NTIseqLdepnT__vAEg9bb6P9cAvzrQae7aeKyA_.marker = Marker_tySequence__vAEg9bb6P9cAvzrQae7aeKyA;
NTIseqLseqLdepnTT__AT39bF59bUK7pfvl9asfwzQ6A_.size = sizeof(tySequence__AT39bF59bUK7pfvl9asfwzQ6A*);
NTIseqLseqLdepnTT__AT39bF59bUK7pfvl9asfwzQ6A_.align = NIM_ALIGNOF(tySequence__AT39bF59bUK7pfvl9asfwzQ6A*);
NTIseqLseqLdepnTT__AT39bF59bUK7pfvl9asfwzQ6A_.kind = 24;
NTIseqLseqLdepnTT__AT39bF59bUK7pfvl9asfwzQ6A_.base = (&NTIseqLdepnT__vAEg9bb6P9cAvzrQae7aeKyA_);
NTIseqLseqLdepnTT__AT39bF59bUK7pfvl9asfwzQ6A_.flags = 2;
NTIseqLseqLdepnTT__AT39bF59bUK7pfvl9asfwzQ6A_.marker = Marker_tySequence__AT39bF59bUK7pfvl9asfwzQ6A;
}

